@@ -1,7 +1,7 @@
 /* cavernlog.cc
  * Run cavern inside an Aven window
  *
- * Copyright (C) 2005,2006 Olly Betts
+ * Copyright (C) 2005,2006,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include "aven.h"
 #include "cavernlog.h"
 #include "filename.h"
+#include "mainfrm.h"
 #include "message.h"
 
 #include <errno.h>
@@ -38,6 +39,13 @@
 #include <sys/types.h>
 #include <unistd.h>
 
+enum { LOG_RERUN = 1234 };
+
+BEGIN_EVENT_TABLE(CavernLogWindow, wxHtmlWindow)
+    EVT_BUTTON(LOG_RERUN, CavernLogWindow::OnRerun)
+    EVT_BUTTON(wxID_OK, CavernLogWindow::OnOK)
+END_EVENT_TABLE()
+
 static wxString escape_for_shell(wxString s, bool protect_dash = false)
 {
     size_t p = 0;
@@ -74,39 +82,12 @@ static wxString escape_for_shell(wxString s, bool protect_dash = false)
     return s;
 }
 
-static wxString
-html_escape(const wxString &str)
+CavernLogWindow::CavernLogWindow(MainFrm * mainfrm_, wxWindow * parent)
+    : wxHtmlWindow(parent), mainfrm(mainfrm_)
 {
-    wxString res;
-    size_t p = 0;
-    while (p < str.size()) {
-	char ch = str[p++];
-	switch (ch) {
-	    case '<':
-		res += wxT("&lt;");
-		continue;
-	    case '>':
-		res += wxT("&gt;");
-		continue;
-	    case '&':
-		res += wxT("&amp;");
-		continue;
-	    case '"':
-		res += wxT("&quot;");
-		continue;
-	    default:
-		res += ch;
-	}
-    }
-    return res;
-}
-
-CavernLogWindow::CavernLogWindow(wxWindow * parent) : wxHtmlWindow(parent) {
-    //GetParser()->SetInputEncoding(wxFONTENCODING_UTF8);
     int fsize = parent->GetFont().GetPointSize();
     int sizes[7] = { fsize, fsize, fsize, fsize, fsize, fsize, fsize };
     SetFonts(wxString(), wxString(), sizes);
-    //GetParser()->SetInputEncoding(wxFONTENCODING_UTF8);
 }
 
 void
@@ -162,13 +143,16 @@ CavernLogWindow::OnLinkClicked(const wxHtmlLinkInfo &link)
 	}
 	// FIXME: This should really use fn_str() - currently we probably can't
 	// process a Unicode path on wxmsw.
-	system(cmd.char_str());
+	system(cmd.mb_str());
     }
 }
 
 int
 CavernLogWindow::process(const wxString &file)
 {
+    SetFocus();
+    filename = file;
+
     char *cavern = use_path(msg_exepth(), "cavern");
 #ifdef __WXMSW__
     SetEnvironmentVariable(wxT("SURVEX_UTF8"), wxT("1"));
@@ -186,7 +170,7 @@ CavernLogWindow::process(const wxString &file)
 
     // FIXME: This should really use fn_str() - currently we probably can't
     // process a Unicode path on wxmsw.
-    FILE * cavern_out = popen(cmd.char_str(), "r");
+    FILE * cavern_out = popen(cmd.mb_str(), "r");
     if (!cavern_out) {
 	wxString m;
 	m.Printf(wmsg(/*Couldn't open pipe: `%s'*/17), cmd.c_str());
@@ -215,9 +199,10 @@ CavernLogWindow::process(const wxString &file)
 	FD_SET(cavern_fd, &rfds);
 	FD_ZERO(&efds);
 	FD_SET(cavern_fd, &efds);
+	// Set timeout to 0.1 seconds.
 	struct timeval timeout;
 	timeout.tv_sec = 0;
-	timeout.tv_usec = 10;
+	timeout.tv_usec = 100000;
 	if (select(cavern_fd + 1, &rfds, NULL, &efds, &timeout) == 0) {
 	    wxYield();
 	    continue;
@@ -261,27 +246,30 @@ CavernLogWindow::process(const wxString &file)
 		break;
 	    case '\n': {
 		if (cur.empty()) continue;
+#ifndef __WXMSW__
 		size_t colon = cur.find(':');
-#ifdef __WXMSW__
+#else
 		// If the path is "C:\path\to\file.svx" then don't split at the
 		// : after the drive letter!  FIXME: better to look for ": "?
-		if (colon == 1) colon = cur.find(':', 2);
+		size_t colon = cur.find(':', 2);
 #endif
-		if (colon != wxString::npos) {
-		    size_t colon2 = cur.find(':', colon + 1);
-		    if (colon2 != wxString::npos && colon2 != cur.size() - 1) {
-			wxString href = cur.substr(0, colon2);
-			while (++colon2 < cur.size()) {
-			    if (cur[colon2] != ' ') break;
-			}
-			wxString title = cur.substr(colon2);
-			cur.insert(colon2, wxT("</a>"));
+		if (colon != wxString::npos && colon < cur.size() - 1) {
+		    ++colon;
+		    size_t i = colon;
+		    while (i < cur.size() - 1 &&
+			   cur[i] >= wxT('0') && cur[i] <= wxT('9')) {
+			++i;
+		    }
+		    if (i > colon && cur[i] == wxT(':') ) {
+			colon = i;
 			wxString tag = wxT("<a href=\"");
-			tag += html_escape(href);
+			tag.append(cur, 0, colon);
+			while (cur[++i] == wxT(' ')) { }
 			tag += wxT("\" target=\"");
-			tag += html_escape(title);
+			tag.append(cur, i, wxString::npos);
 			tag += wxT("\">");
 			cur.insert(0, tag);
+			cur.insert(colon + tag.size(), wxT("</a>"));
 			++link_count;
 		    }
 		}
@@ -293,9 +281,6 @@ CavernLogWindow::process(const wxString &file)
 		cur += wxT("<br>\n");
 		AppendToPage(cur);
 
-		// Restore the scrollbar positions.
-		Scroll(scroll_x, scroll_y);
-
 		if (!link_count) {
 		    // Auto-scroll the window until we've reported a warning or
 		    // error.
@@ -306,10 +291,14 @@ CavernLogWindow::process(const wxString &file)
 		    y -= ys;
 		    int xu, yu;
 		    GetScrollPixelsPerUnit(&xu, &yu);
-		    Scroll(-1, y / yu);
+		    Scroll(scroll_x, y / yu);
+		} else {
+		    // Restore the scrollbar positions.
+		    Scroll(scroll_x, scroll_y);
 		}
+
 		cur.clear();
-		wxYield();
+		Update();
 		break;
 	    }
 	    case '<':
@@ -321,6 +310,9 @@ CavernLogWindow::process(const wxString &file)
 	    case '&':
 		cur += wxT("&amp;");
 		break;
+	    case '"':
+		cur += wxT("&#22;");
+		continue;
 	    default:
 		if (ch >= 128) {
 		    cur += wxString::Format(wxT("&#%u;"), ch);
@@ -328,18 +320,38 @@ CavernLogWindow::process(const wxString &file)
 		    cur += (char)ch;
 		}
 	}
-	ch = left;
     }
+
     int retval = pclose(cavern_out);
     if (retval) {
+	AppendToPage(wxT("<avenbutton default id=1234 name=\"Rerun\">"));
 	if (retval == -1) {
 	    wxString m = wxT("Problem running cavern: ");
 	    m += wxString(strerror(errno), wxConvUTF8);
 	    wxGetApp().ReportError(m);
 	    return -2;
 	}
-	wxGetApp().ReportError(wxT("Failed to process survey data - see log window for details"));
 	return -1;
     }
+    if (link_count) {
+	AppendToPage(wxT("<avenbutton id=1234 name=\"Rerun\">"));
+	AppendToPage(wxString::Format(wxT("<avenbutton default id=%d>"), (int)wxID_OK));
+	Update();
+    }
     return link_count;
 }
+
+void
+CavernLogWindow::OnRerun(wxCommandEvent & e)
+{
+    SetPage(wxString());
+    if (process(filename) == 0) {
+	OnOK(e);
+    }
+}
+
+void
+CavernLogWindow::OnOK(wxCommandEvent &)
+{
+    mainfrm->InitialiseAfterLoad(filename);
+}
