@@ -1,7 +1,7 @@
-/* cavernlog.cc
+/* cavernlog.h
  * Run cavern inside an Aven window
  *
- * Copyright (C) 2005,2006 Olly Betts
+ * Copyright (C) 2005,2006,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,14 +24,30 @@
 #include "wx.h"
 #include <wx/html/htmlwin.h>
 
-class CavernLogWindow : public wxHtmlWindow {
-  public:
-    CavernLogWindow(wxWindow * parent);
+class MainFrm;
 
-    /// Returns -2 on failure to run cavern, -1 on error, or the number of warnings if no error.
+class CavernLogWindow : public wxHtmlWindow {
+    wxString filename;
+
+    MainFrm * mainfrm;
+
+  public:
+    CavernLogWindow(MainFrm * mainfrm_, wxWindow * parent);
+
+    /** Process survey data in file.
+     *
+     *  @return -2 on failure to run cavern, -1 on error from cavern, or the
+     *		number of warnings if no errors.
+     */
     int process(const wxString &file);
 
     virtual void OnLinkClicked(const wxHtmlLinkInfo &link);
+
+    void OnRerun(wxCommandEvent &);
+
+    void OnOK(wxCommandEvent &);
+
+    DECLARE_EVENT_TABLE()
 };
 
 #endif
