@@ -1006,7 +1006,7 @@ Export(const wxString &fnm_out, const wxString &title, const MainFrm * mainfrm,
 
    // FIXME: This should really use fn_str() - currently we probably can't
    // save to a Unicode path on wxmsw.
-   if (!filt->fopen(fnm_out.char_str())) {
+   if (!filt->fopen(fnm_out.mb_str())) {
        delete filt;
        return false;
    }
