@@ -45,6 +45,13 @@ class traverse;
 
 extern const int NUM_DEPTH_COLOURS;
 
+// Mac OS X headers pollute the global namespace with generic names like
+// "class Point", which clashes with our "class Point".  So for __WXMAC__
+// put our class in a namespace and pull it in from that with "using".
+#ifdef __WXMAC__
+namespace svx {
+#endif
+
 class Point : public Vector3 {
   public:
     Point() {}
@@ -57,6 +64,11 @@ class Point : public Vector3 {
     bool IsValid() const { return x != DBL_MAX; }
 };
 
+#ifdef __WXMAC__
+}
+using svx::Point;
+#endif
+
 class XSect;
 class LabelInfo;
 class PointInfo;
