@@ -144,15 +144,15 @@ public:
     }
     PresentationMark GetMark() const {
 	double a, t, s, T;
-	Vector3 v(atof(easting->GetValue().char_str()),
-		  atof(northing->GetValue().char_str()),
-		  atof(altitude->GetValue().char_str()));
-	a = atof(angle->GetValue().char_str());
-	t = atof(tilt_angle->GetValue().char_str());
-	s = atof(scale->GetValue().char_str());
+	Vector3 v(atof(easting->GetValue().mb_str()),
+		  atof(northing->GetValue().mb_str()),
+		  atof(altitude->GetValue().mb_str()));
+	a = atof(angle->GetValue().mb_str());
+	t = atof(tilt_angle->GetValue().mb_str());
+	s = atof(scale->GetValue().mb_str());
 	wxString str = time->GetValue();
 	if (str[0u] == '*') str[0u] = '-';
-	T = atof(str.char_str());
+	T = atof(str.mb_str());
 	return PresentationMark(v, a, t, s, T);
     }
 
@@ -318,7 +318,7 @@ class AvenPresList : public wxListCtrl {
 
 	    // FIXME: This should really use fn_str() - currently we probably can't
 	    // save to a Unicode path on wxmsw.
-	    FILE * fh_pres = fopen(fnm.char_str(), "w");
+	    FILE * fh_pres = fopen(fnm.mb_str(), "w");
 	    if (!fh_pres) {
 		wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file `%s'*/110), fnm.c_str()));
 		return;
@@ -357,7 +357,7 @@ class AvenPresList : public wxListCtrl {
 	bool Load(const wxString &fnm) {
 	    // FIXME: This should really use fn_str() - currently we probably
 	    // can't save to a Unicode path on wxmsw.
-	    FILE * fh_pres = fopen(fnm.char_str(), "r");
+	    FILE * fh_pres = fopen(fnm.mb_str(), "r");
 	    if (!fh_pres) {
 		wxString m;
 		m.Printf(wmsg(/*Couldn't open file `%s'*/93), fnm.c_str());
@@ -660,7 +660,7 @@ DnDFile::OnDropFiles(wxCoord, wxCoord, const wxArrayString &filenames)
 #endif
 
 MainFrm::MainFrm(const wxString& title, const wxPoint& pos, const wxSize& size) :
-    wxFrame(NULL, 101, title, pos, size, wxDEFAULT_FRAME_STYLE | wxNO_FULL_REPAINT_ON_RESIZE), // wxNO_FULL_REPAINT_ON_RESIZE is 0 in wx >= 2.6
+    wxFrame(NULL, 101, title, pos, size, wxDEFAULT_FRAME_STYLE),
     m_Gfx(NULL), m_NumEntrances(0), m_NumFixedPts(0), m_NumExportedPts(0),
     m_NumHighlighted(0), m_HasUndergroundLegs(false), m_HasSurfaceLegs(false),
     m_HasErrorInformation(false), m_IsExtendedElevation(false)
@@ -949,26 +949,8 @@ void MainFrm::CreateSidePanel()
     m_Splitter->Initialize(m_Gfx);
 }
 
-bool
-MainFrm::ProcessSVXFile(const wxString & file)
+bool MainFrm::LoadData(const wxString& file, wxString prefix)
 {
-    Show(true);
-    m_Splitter->Show(false);
-    CavernLogWindow * log = new CavernLogWindow(this);
-    m_Splitter->ReplaceWindow(m_Gfx, log);
-
-    int result = log->process(file);
-    if (result == 0) {
-	m_Splitter->ReplaceWindow(log, m_Gfx);
-	m_Splitter->Show();
-	log->Destroy();
-    }
-    return result >= 0;
-}
-
-bool MainFrm::LoadData(const wxString& file_, wxString prefix)
-{
-    wxString file(file_);
     // Load survey data from file, centre the dataset around the origin,
     // and prepare the data for drawing.
 
@@ -976,37 +958,15 @@ bool MainFrm::LoadData(const wxString& file_, wxString prefix)
     wxStopWatch timer;
     timer.Start();
 #endif
-    wxString filename_used;
 
-    // Check if this is an unprocessed survey data file.
-    if (file.length() > 4 && file[file.length() - 4] == '.') {
-	wxString ext = file.substr(file.length() - 3, 3);
-	if (strcasecmp(ext.char_str(), "svx") == 0 ||
-	    strcasecmp(ext.char_str(), "dat") == 0 ||
-	    strcasecmp(ext.char_str(), "mak") == 0) {
-	    if (!ProcessSVXFile(file)) return false;
-	    filename_used = file;
-	    char * base_fnm = base_from_fnm(file.char_str());
-	    char * fnm_3d = add_ext(base_fnm, "3d");
-	    file = wxString(fnm_3d, wxConvUTF8);
-	    osfree(fnm_3d);
-	    osfree(base_fnm);
-	}
-    }
-
-    // Load the survey data.
-    img* survey = img_open_survey(file.char_str(), prefix.char_str());
+    // Load the processed survey data.
+    img* survey = img_open_survey(file.mb_str(), prefix.mb_str());
     if (!survey) {
 	wxString m = wxString::Format(wmsg(img_error()), file.c_str());
 	wxGetApp().ReportError(m);
 	return false;
     }
 
-    if (!filename_used.empty()) {
-	m_File = filename_used;
-    } else {
-	m_File = wxString(survey->filename_opened, wxConvUTF8);
-    }
     m_IsExtendedElevation = survey->is_extended_elevation;
 
     m_Tree->DeleteAllItems();
@@ -1352,6 +1312,12 @@ bool MainFrm::LoadData(const wxString& file_, wxString prefix)
     // Update window title.
     SetTitle(m_Title + " - "APP_NAME);
 
+    if (!m_FindBox->GetValue().empty()) {
+	// Highlight any stations matching the current search.
+	wxCommandEvent dummy;
+	OnFind(dummy);
+    }
+
     return true;
 }
 
@@ -1609,42 +1575,97 @@ void MainFrm::OnMRUFile(wxCommandEvent& event)
     if (!f.empty()) OpenFile(f);
 }
 
+void MainFrm::AddToFileHistory(const wxString & file)
+{
+    if (wxIsAbsolutePath(file)) {
+	m_history.AddFileToHistory(file);
+    } else {
+	wxString abs = wxGetCwd();
+	abs += wxCONFIG_PATH_SEPARATOR;
+	abs += file;
+	m_history.AddFileToHistory(abs);
+    }
+    wxConfigBase *b = wxConfigBase::Get();
+    m_history.Save(*b);
+    b->Flush();
+}
+
 void MainFrm::OpenFile(const wxString& file, wxString survey)
 {
     wxBusyCursor hourglass;
-    wxString old_file = m_File;
-    if (LoadData(file, survey)) {
-	if (wxIsAbsolutePath(m_File)) {
-	    m_history.AddFileToHistory(m_File);
-	} else {
-	    wxString abs = wxGetCwd();
-	    abs += wxCONFIG_PATH_SEPARATOR;
-	    abs += m_File;
-	    m_history.AddFileToHistory(abs);
+
+    // Check if this is an unprocessed survey data file.
+    if (file.length() > 4 && file[file.length() - 4] == '.') {
+	wxString ext(file, file.length() - 3, 3);
+	ext.MakeLower();
+	if (ext == wxT("svx") || ext == wxT("dat") || ext == wxT("mak")) {
+	    CavernLogWindow * log = new CavernLogWindow(this, m_Splitter);
+	    wxWindow * win = m_Splitter->GetWindow1();
+	    m_Splitter->ReplaceWindow(win, log);
+	    if (m_Splitter->GetWindow2() == NULL) {
+		if (win != m_Gfx) win->Destroy();
+	    } else {
+		if (m_Splitter->IsSplit()) m_Splitter->Unsplit();
+	    }
+
+	    int result = log->process(file);
+	    if (result < 0) {
+		// Error running cavern or processing data.
+		return;
+	    }
+
+	    AddToFileHistory(file);
+	    wxString file3d(file, 0, file.length() - 3);
+	    file3d.append(wxT("3d"));
+	    if (!LoadData(file3d, survey))
+		return;
+	    if (result == 0) {
+		InitialiseAfterLoad(file);
+	    }
+	    return;
 	}
-	wxConfigBase *b = wxConfigBase::Get();
-	m_history.Save(*b);
-	b->Flush();
-
-	int x;
-	int y;
-	GetClientSize(&x, &y);
-	if (x < 600)
-	    x /= 3;
-	else if (x < 1000)
-	    x = 200;
-	else
-	    x /= 5;
-
-	m_Splitter->SplitVertically(m_Notebook, m_Gfx, x);
-	m_SashPosition = x; // Save width of panel.
-
-	m_Gfx->Initialise(old_file == m_File);
-	m_Notebook->Show(true);
-
-	m_Gfx->Show(true);
-	m_Gfx->SetFocus();
     }
+
+    if (!LoadData(file, survey))
+	return;
+    AddToFileHistory(file);
+    InitialiseAfterLoad(file);
+}
+
+void MainFrm::InitialiseAfterLoad(const wxString & file)
+{
+    int x;
+    int y;
+    GetClientSize(&x, &y);
+    if (x < 600)
+	x /= 3;
+    else if (x < 1000)
+	x = 200;
+    else
+	x /= 5;
+
+    // Do this before we potentially delete the log window which may own the
+    // wxString which parameter file refers to!
+    bool same_file = (file == m_File);
+    if (!same_file)
+	m_File = file;
+
+    wxWindow * win = NULL;
+    if (m_Splitter->GetWindow2() == NULL) {
+	win = m_Splitter->GetWindow1();
+	if (win == m_Gfx) win = NULL;
+    }
+
+    m_Splitter->SplitVertically(m_Notebook, m_Gfx, x);
+    m_SashPosition = x; // Save width of panel.
+
+    m_Gfx->Initialise(same_file);
+    m_Notebook->Show(true);
+
+    m_Gfx->Show(true);
+    m_Gfx->SetFocus();
+
+    if (win) win->Destroy();
 }
 
 //
