@@ -263,10 +263,14 @@ class MainFrm : public wxFrame {
 
     void UpdateStatusBar();
 
+    void AddToFileHistory(const wxString & file);
+
 public:
     MainFrm(const wxString& title, const wxPoint& pos, const wxSize& size);
     ~MainFrm();
 
+    void InitialiseAfterLoad(const wxString & file);
+
     void OnMRUFile(wxCommandEvent& event);
     void OpenFile(const wxString& file, wxString survey = wxString());
 
@@ -534,7 +538,7 @@ private:
     DECLARE_EVENT_TABLE()
 };
 
-// wxGtk loses the dialog under the always-on-top, maximised window.
+// wxGTK loses the dialog under the always-on-top, maximised window.
 // By creating this object on the stack, you can get the dialog on top...
 class AvenAllowOnTop {
 #ifndef _WIN32
