@@ -1,6 +1,6 @@
 /* osdepend.h
  * Contains commonly required OS dependent bits
- * Copyright (C) 1993-2003,2004,2005 Olly Betts
+ * Copyright (C) 1993-2003,2004,2005,2010 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,8 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/* Note to porters: defaults are at the end of the file. Check there first */
-
 #ifndef OSDEPEND_H  /* only include once */
 # define OSDEPEND_H
 
@@ -47,35 +45,12 @@
 /* #  define FNM_SEP_DRV  No equivalent under UNIX */
 #  define FNM_SEP_EXT '.'
 
-#  define NO_STDPRN
-
 # else
 #  error Do not know what to do for this operating system
 # endif
 
 /***************************************************************************/
 
-/* Use "Far" rather than "FAR" to avoid colliding with windows headers
- * which may "#define FAR far" and "#define far" or something similar.
- *
- * Use "Huge" to avoid colliding with "HUGE" which is a pre-ANSI name for
- * "HUGE_VAL"
- */
-# ifdef HAVE_FAR_POINTERS
-#  define Far far
-#  define Huge huge
-# else
-/* just lose these on a sensible OS */
-#  define Far
-#  define Huge
-# endif /* !Huge */
-
-/* defaults for things that are the same for most OS */
-
-# ifndef init_screen
-#  define init_screen() /* ie do nothing special */
-# endif /* !init_screen */
-
 /* prototypes for functions in osdepend.c */
 bool fAbsoluteFnm(const char *fnm);
 bool fDirectory(const char *fnm);
